@@ -3,9 +3,7 @@
 Test suite for the community-developed Python SDK for interacting with Lacework APIs.
 """
 
-import pytest
-
-from laceworksdk.api.recommendations import RecommendationsAPI
+from laceworksdk.api.v1.recommendations import RecommendationsAPI
 
 
 # Tests
@@ -28,7 +26,6 @@ def test_recommendations_api_get_gcp(api):
     assert response["ok"]
 
 
-@pytest.mark.ci_exempt
 def test_recommendations_api_update_aws(api):
     data = {
         "LW_S3_1": "disable"
